# pyultrasonic

Retrieve distances using a Raspberry Pi with ultrasonic sensor HC-SR04

# WIP WIP WIP

# TODO

* multiple output types
  * text
  * influxdb
  * json
* Error handling
* No GPIO jumpers connected detection
